# MLGuard 

Lightweight Python library for automated machine learning model checks:

- Bias Detection (group fairness check)
- Class Imbalance Detection
- Multicollinearity Detection
- Overfitting/Underfitting Detection (using learning curves)

---

## Installation

```bash
pip install mlguard
